@@ -9,5 +9,5 @@ class PongApp(App):
     def build(self):
         return PongGame()
 
-if __name__ in ('__android__', '__main__'):
+if __name__ == '__main__':
     PongApp().run()
