@@ -24,11 +24,11 @@ __all__ = (
     'kivy_configure', 'kivy_register_post_configuration',
     'kivy_options', 'kivy_base_dir',
     'kivy_modules_dir', 'kivy_data_dir', 'kivy_shader_dir',
-    'kivy_icons_dir', 'kivy_home_dir',
+    'kivy_icons_dir', 'kivy_home_dir', 'kivy_userexts_dir',
     'kivy_config_fn', 'kivy_usermodules_dir',
 )
 
-__version__ = '1.3.0'
+__version__ = '1.4.0'
 
 import sys
 import shutil
@@ -43,7 +43,7 @@ __kivy_post_configuration = []
 
 
 if platform() == 'macosx' and sys.maxint < 9223372036854775807:
-    r ='''Unsupported Python version detected!:
+    r = '''Unsupported Python version detected!:
     Kivy requires a 64 bit version of Python to run on OS X. We strongly advise
     you to use the version of Python that is provided by Apple (don't use ports,
     fink or homebrew unless you know what you're doing).
@@ -112,7 +112,7 @@ def require(version):
     if tag == 'dev' and systag != 'dev':
         Logger.warning('Application requested a -dev version of Kivy. '
                        '(You have %s, but the application requires %s)' % (
-                            __version__, version))
+                           __version__, version))
     # not tag rev (-alpha-1, -beta-x) allowed.
     if tagrev is not None:
         raise Exception('Revision format must not contain any tagrevision')
@@ -143,7 +143,7 @@ def kivy_register_post_configuration(callback):
 
 
 def kivy_usage():
-    '''Kivy Usage: %s [OPTION...] ::
+    '''Kivy Usage: %s [OPTION...]::
 
         -h, --help
             Prints this help message.
@@ -224,20 +224,24 @@ kivy_shader_dir = join(kivy_data_dir, 'glsl')
 #: Kivy icons config path (don't remove the last '')
 kivy_icons_dir = join(kivy_data_dir, 'icons', '')
 #: Kivy user-home storage directory
-kivy_home_dir = None
+kivy_home_dir = ''
 #: Kivy configuration filename
-kivy_config_fn = None
+kivy_config_fn = ''
 #: Kivy user modules directory
-kivy_usermodules_dir = None
+kivy_usermodules_dir = ''
+#: Kivy user extensions directory
+kivy_userexts_dir = ''
+
 
 # Don't go further if we generate documentation
-if basename(sys.argv[0]) in ('sphinx-build', 'autobuild.py'):
+if any(name in sys.argv[0] for name in ('sphinx-build', 'autobuild.py')):
     environ['KIVY_DOC'] = '1'
-if basename(sys.argv[0]) in ('sphinx-build', ):
+if 'sphinx-build' in sys.argv[0]:
     environ['KIVY_DOC_INCLUDE'] = '1'
-if basename(sys.argv[0]) in ('nosetests', ) or 'nosetests' in sys.argv:
+if any('nosetests' in arg for arg in sys.argv):
     environ['KIVY_UNITTEST'] = '1'
-if not 'KIVY_DOC_INCLUDE' in environ:
+
+if not environ.get('KIVY_DOC_INCLUDE'):
     # Configuration management
     user_home_dir = expanduser('~')
     if platform() == 'android':
@@ -269,7 +273,6 @@ if not 'KIVY_DOC_INCLUDE' in environ:
     Logger.setLevel(level=level)
     Logger.setLevel(level=LOG_LEVELS.get('debug'))
 
-
     # Can be overrided in command line
     if 'KIVY_UNITTEST' not in environ:
 
@@ -294,7 +297,6 @@ if not 'KIVY_DOC_INCLUDE' in environ:
         opts = []
         args = []
 
-
     need_save = False
     for opt, arg in opts:
         if opt in ('-h', '--help'):
