@@ -151,7 +151,7 @@ However, you might want to know when a config value has been changed by the
 user, in order to adapt or reload your UI. You can overload the
 :meth:`on_config_change` method::
 
-    class TestApp(self):
+    class TestApp(App):
         # ...
         def on_config_change(self, config, section, key, value):
             if config is self.config:
@@ -211,17 +211,20 @@ The current implemented Pause mechanism is:
 __all__ = ('App', )
 
 from inspect import getfile
-from os.path import dirname, join, exists
+from os.path import dirname, join, exists, sep, expanduser
 from kivy.config import ConfigParser
 from kivy.base import runTouchApp, stopTouchApp
 from kivy.logger import Logger
 from kivy.event import EventDispatcher
 from kivy.lang import Builder
 from kivy.resources import resource_find
-from kivy.utils import platform
+from kivy.utils import platform as core_platform
 from kivy.uix.widget import Widget
 
 
+platform = core_platform()
+
+
 class App(EventDispatcher):
     ''' Application class, see module documentation for more information.
 
@@ -231,6 +234,12 @@ class App(EventDispatcher):
             :func:`~kivy.base.runTouchApp` call.
         `on_stop`:
             Fired when the application stops.
+        `on_pause`:
+            Fired when the application is paused by the OS.
+        `on_resume`:
+            Fired when the application is resumed from pause by the OS, beware,
+            you have no garantee that this event will be fired after the
+            on_pause event has been called.
 
     :Parameters:
         `kv_directory`: <path>, default to None
@@ -290,8 +299,8 @@ class App(EventDispatcher):
         #: configuration. Can be used to query some config token in the build()
         self.config = None
 
-        #: Root widget set by the :func:`build` method or by the
-        #: :func:`load_kv` method if the kv file contains a root widget.
+        #: Root widget set by the :meth:`build` method or by the
+        #: :meth:`load_kv` method if the kv file contains a root widget.
         self.root = None
 
     def build(self):
@@ -300,7 +309,7 @@ class App(EventDispatcher):
         widget and added to the window.
 
         :return: None or a root :class:`~kivy.uix.widget.Widget` instance is no
-        self.root exist.
+                 self.root exist.
         '''
         if not self.root:
             return Widget()
@@ -361,6 +370,8 @@ class App(EventDispatcher):
         '''
         try:
             default_kv_directory = dirname(getfile(self.__class__))
+            if default_kv_directory == '':
+                default_kv_directory = '.'
         except TypeError:
             # if it's a builtin module.. use the current dir.
             default_kv_directory = '.'
@@ -390,16 +401,52 @@ class App(EventDispatcher):
     def get_application_icon(self):
         '''Return the icon of the application.
         '''
-        if self.icon is not None:
+        if not resource_find(self.icon):
+            return ''
+        else:
             return resource_find(self.icon)
-        return None
 
-    def get_application_config(self):
+    def get_application_config(self, defaultpath='%(appdir)s/%(appname)s.ini'):
         '''.. versionadded:: 1.0.7
 
-        Return the filename of your application configuration
+        .. versionchanged:: 1.4.0
+            Customize the default path for iOS and Android platform. Add
+            defaultpath parameter for desktop computer (not applicatable for iOS
+            and Android.)
+
+        Return the filename of your application configuration. Depending the
+        platform, the application file will be stored at different places:
+
+            - on iOS: <appdir>/Documents/.<appname>.ini
+            - on Android: /sdcard/.<appname>.ini
+            - otherwise: <appdir>/<appname>.ini
+
+        When you are distributing your application on Desktop, please note than
+        if the application is meant to be installed system-wise, then the user
+        might not have any write-access to the application directory. You could
+        overload this method to change the default behavior, and save the
+        configuration file in the user directory by default::
+
+            class TestApp(App):
+                def get_application_config(self):
+                    return super(TestApp, self).get_application_config(
+                        '~/.%(appname)s.ini')
+
+        Some notes:
+
+        - The tilda '~' will be expanded to the user directory.
+        - %(appdir)s will be replaced with the application :data:`directory`
+        - %(appname)s will be replaced with the application :data:`name`
         '''
-        return join(self.directory, '%s.ini' % self.name)
+
+        if platform == 'android':
+            defaultpath = '/sdcard/.%(appname)s.ini'
+        elif platform == 'ios':
+            defaultpath = '~/Documents/%(appname)s.ini'
+        elif platform == 'win':
+            defaultpath = defaultpath.replace('/', sep)
+        return expanduser(defaultpath) % {
+            'appname': self.name, 'appdir': self.directory}
 
     def load_config(self):
         '''(internal) This function is used for returning a ConfigParser with
@@ -446,6 +493,8 @@ class App(EventDispatcher):
         if self._app_directory is None:
             try:
                 self._app_directory = dirname(getfile(self.__class__))
+                if self._app_directory == '':
+                    self._app_directory = '.'
             except TypeError:
                 # if it's a builtin module.. use the current dir.
                 self._app_directory = '.'
@@ -610,7 +659,7 @@ class App(EventDispatcher):
         setting_key = 282  # F1
 
         # android hack, if settings key is pygame K_MENU
-        if platform() == 'android':
+        if platform == 'android':
             import pygame
             setting_key = pygame.K_MENU
 
