@@ -112,12 +112,14 @@ class SoundGstreamer(Sound):
                 self._data.set_state(gst.STATE_PLAYING)
                 try:
                     self._data.get_state()
-                    return self._data.query_duration(gst.Format(gst.FORMAT_TIME))[0] / 1000000000.
+                    return self._data.query_duration(gst.Format(
+                        gst.FORMAT_TIME))[0] / 1000000000.
                 finally:
                     self._data.set_state(gst.STATE_NULL)
                     self._data.set_property('volume', volume_before)
             else:
-                return self._data.query_duration(gst.Format(gst.FORMAT_TIME))[0] / 1000000000.
+                return self._data.query_duration(gst.Format
+                        (gst.FORMAT_TIME))[0] / 1000000000.
         return super(SoundGstreamer, self)._get_length()
 
 SoundLoader.register(SoundGstreamer)
