@@ -103,9 +103,10 @@ class WindowPygame(WindowBase):
 
         # set window icon before calling set_mode
         try:
-            filename_icon = Config.get('kivy', 'window_icon')
+            #filename_icon = Config.get('kivy', 'window_icon')
+            filename_icon = self.icon or Config.get('kivy', 'window_icon')
             if filename_icon == '':
-                logo_size = 512 if platform() == 'darwin' else 32
+                logo_size = 512 if platform() == 'macosx' else 32
                 filename_icon = join(kivy_home_dir, 'icon', 'kivy-icon-%d.png' %
                         logo_size)
             self.set_icon(filename_icon)
@@ -164,6 +165,7 @@ class WindowPygame(WindowBase):
             if im is None:
                 raise Exception('Unable to load window icon (not found)')
             pygame.display.set_icon(im)
+            super(WindowPygame, self).set_icon(filename)
         except:
             Logger.exception('WinPygame: unable to set icon')
 
@@ -191,7 +193,7 @@ class WindowPygame(WindowBase):
         is_osx = platform() == 'darwin'
         if key == 27 or (is_osx and key in (113, 119) and modifier == 1024):
             stopTouchApp()
-            self.close()  #not sure what to do here
+            self.close()  # not sure what to do here
             return True
         super(WindowPygame, self).on_keyboard(key, scancode,
             codepoint=codepoint, modifier=modifier)
@@ -343,7 +345,7 @@ class WindowPygame(WindowBase):
 
     def request_keyboard(self, *largs):
         keyboard = super(WindowPygame, self).request_keyboard(*largs)
-        if android:
+        if android and not self.allow_vkeyboard:
             android.show_keyboard()
         return keyboard
 
