@@ -265,7 +265,7 @@ For example, for a list, you'll need to create a entry with a image on the left,
 and a label on the right. You can create a template for making that definition
 more easy to use.
 So, we'll create a template that require 2 entry in the context: a image
-filename and a title ::
+filename and a title::
 
     [IconItem@BoxLayout]:
         Image:
@@ -275,7 +275,7 @@ filename and a title ::
 
 .. highlight:: python
 
-Then in Python, you can create instanciate the template with ::
+Then in Python, you can create instanciate the template with::
 
     from kivy.lang import Builder
 
@@ -488,12 +488,12 @@ class ParserException(Exception):
         sc = ['...']
         sc += ['   %4d:%s' % x for x in sourcecode[sc_start:line]]
         sc += ['>> %4d:%s' % (line, sourcecode[line][1])]
-        sc += ['   %4d:%s' % x for x in sourcecode[line+1:sc_stop]]
+        sc += ['   %4d:%s' % x for x in sourcecode[line + 1:sc_stop]]
         sc += ['...']
         sc = '\n'.join(sc)
 
         message = 'Parser: File "%s", line %d:\n%s\n%s' % (
-            self.filename, self.line+1, sc, message)
+                self.filename, self.line + 1, sc, message)
         super(ParserException, self).__init__(message)
 
 
@@ -507,7 +507,7 @@ class ParserRuleProperty(object):
     '''Represent a property inside a rule
     '''
 
-    __slots__ = ('ctx', 'line', 'name', 'value', 'co_value', \
+    __slots__ = ('ctx', 'line', 'name', 'value', 'co_value',
             'watched_keys', 'mode')
 
     def __init__(self, ctx, line, name, value):
@@ -559,8 +559,8 @@ class ParserRuleProperty(object):
     def __repr__(self):
         return '<ParserRuleProperty name=%r filename=%s:%d' \
                'value=%r watched_keys=%r>' % (
-                self.name, self.ctx.filename, self.line + 1,
-                self.value, self.watched_keys)
+                       self.name, self.ctx.filename, self.line + 1,
+                       self.value, self.watched_keys)
 
 
 class ParserRule(object):
@@ -825,7 +825,7 @@ class Parser(object):
             tmp = content.lstrip(' \t')
 
             # Replace any tab with 4 spaces
-            tmp = content[:len(content)-len(tmp)]
+            tmp = content[:len(content) - len(tmp)]
             tmp = tmp.replace('\t', '    ')
             count = len(tmp)
 
@@ -838,7 +838,7 @@ class Parser(object):
 
             # Level finished
             if count < indent:
-                return objects, lines[i-1:]
+                return objects, lines[i - 1:]
 
             # Current level, create an object
             elif count == indent:
@@ -1029,7 +1029,7 @@ class ParserSelectorName(ParserSelector):
         parents = ParserSelectorName.parents
         cls = widget.__class__
         if not cls in parents:
-            classes = [x.__name__.lower() for x in \
+            classes = [x.__name__.lower() for x in
                        [cls] + list(self.get_bases(cls))]
             parents[cls] = classes
         return self.key in parents[cls]
@@ -1231,6 +1231,8 @@ class BuilderBase(object):
                 ctx = {}
                 idmap = copy(global_idmap)
                 idmap.update({'root': rctx['ids']['root']})
+                if 'ctx' in rctx['ids']:
+                    idmap.update({'ctx': rctx['ids']['ctx']})
                 try:
                     for prule in crule.properties.itervalues():
                         value = prule.co_value
