@@ -3,18 +3,14 @@ Test properties attached to a widget
 '''
 
 import unittest
+from kivy.event import EventDispatcher
 
 
-class Widget(object):
-    '''Fake widget class'''
-
-    def __init__(self, **kwargs):
-        super(Widget, self).__init__(**kwargs)
-        self.__dict__['__uid'] = 1
-        self.__dict__['__storage'] = {}
+class TestProperty(EventDispatcher):
+    pass
 
 
-wid = Widget()
+wid = TestProperty()
 
 
 class PropertiesTestCase(unittest.TestCase):
@@ -78,7 +74,7 @@ class PropertiesTestCase(unittest.TestCase):
         self.assertEqual(a.get(wid), 'hello')
 
         try:
-            a.set(wid, 88) # number shouldn't be accepted
+            a.set(wid, 88)  # number shouldn't be accepted
             self.fail('string accept number, fail.')
         except ValueError:
             pass
@@ -94,7 +90,7 @@ class PropertiesTestCase(unittest.TestCase):
         self.assertEqual(a.get(wid), 99)
 
         try:
-            a.set(wid, '') # string shouldn't be accepted
+            a.set(wid, '')  # string shouldn't be accepted
             self.fail('number accept string, fail.')
         except ValueError:
             pass
@@ -119,7 +115,6 @@ class PropertiesTestCase(unittest.TestCase):
         a.set(wid, {'foo': 'bar'})
         self.assertEqual(a.get(wid), {'foo': 'bar'})
 
-
     def test_propertynone(self):
         from kivy.properties import NumericProperty
 
@@ -270,3 +265,49 @@ class PropertiesTestCase(unittest.TestCase):
         x.get(wid).update({'bleh': 5})
         self.assertEqual(observe_called, 1)
 
+    def test_aliasproperty_with_cache(self):
+        from kivy.properties import NumericProperty, AliasProperty
+        global observe_called
+
+        class CustomAlias(EventDispatcher):
+            basevalue = NumericProperty(1)
+
+            def _get_prop(self):
+                global observe_called
+                observe_called += 1
+                return self.basevalue * 2
+
+            def _set_prop(self, value):
+                self.basevalue = value / 2
+
+            prop = AliasProperty(_get_prop, _set_prop,
+                    bind=('basevalue', ), cache=True)
+
+        # initial checks
+        wid = CustomAlias()
+        self.assertEqual(observe_called, 0)
+        self.assertEqual(wid.basevalue, 1)
+        self.assertEqual(observe_called, 0)
+
+        # first call, goes in cache
+        self.assertEqual(wid.prop, 2)
+        self.assertEqual(observe_called, 1)
+
+        # second call, cache used
+        self.assertEqual(wid.prop, 2)
+        self.assertEqual(observe_called, 1)
+
+        # change the base value, should trigger an update for the cache
+        wid.basevalue = 4
+        self.assertEqual(observe_called, 2)
+
+        # now read the value again, should use the cache too
+        self.assertEqual(wid.prop, 8)
+        self.assertEqual(observe_called, 2)
+
+        # change the prop itself, should trigger an update for the cache
+        wid.prop = 4
+        self.assertEqual(observe_called, 3)
+        self.assertEqual(wid.basevalue, 2)
+        self.assertEqual(wid.prop, 4)
+        self.assertEqual(observe_called, 3)
