@@ -16,7 +16,7 @@ Anchor Layout
 or center.
 
 
-To draw a button in the lower-right corner ::
+To draw a button in the lower-right corner::
 
     layout = AnchorLayout(
         anchor_x='right', anchor_y='bottom')
@@ -47,7 +47,7 @@ class AnchorLayout(Layout):
     '''Horizontal anchor.
 
     :data:`anchor_x` is an :class:`~kivy.properties.OptionProperty`, default
-    to 'center'. Can take a value of 'left', 'center' or 'right'
+    to 'center'. Can take a value of 'left', 'center' or 'right'.
     '''
 
     anchor_y = OptionProperty('center', options=(
@@ -55,18 +55,19 @@ class AnchorLayout(Layout):
     '''Vertical anchor.
 
     :data:`anchor_y` is an :class:`~kivy.properties.OptionProperty`, default
-    to 'center'. Can take a value of 'top', 'center' or 'bottom'
+    to 'center'. Can take a value of 'top', 'center' or 'bottom'.
     '''
 
     def __init__(self, **kwargs):
         super(AnchorLayout, self).__init__(**kwargs)
         self.bind(
-            parent = self._trigger_layout,
-            padding = self._trigger_layout,
-            anchor_x = self._trigger_layout,
-            anchor_y = self._trigger_layout,
-            size = self._trigger_layout,
-            pos = self._trigger_layout)
+            children=self._trigger_layout,
+            parent=self._trigger_layout,
+            padding=self._trigger_layout,
+            anchor_x=self._trigger_layout,
+            anchor_y=self._trigger_layout,
+            size=self._trigger_layout,
+            pos=self._trigger_layout)
 
     def do_layout(self, *largs):
         _x, _y = self.pos
@@ -85,7 +86,7 @@ class AnchorLayout(Layout):
             elif not self.size_hint[0]:
                 width = max(width, c.width)
             if c.size_hint[1]:
-                h = c.size_hint[1]*height
+                h = c.size_hint[1] * height
             elif not self.size_hint[1]:
                 height = max(height, c.height)
 
@@ -104,4 +105,4 @@ class AnchorLayout(Layout):
 
             reposition_child(c, pos=(x, y), size=(w, h))
 
-        self.size = (width, height) # might have changed inside loop
+        self.size = (width, height)  # might have changed inside loop
