@@ -43,7 +43,7 @@ example, we use 10 pixel spacing between children; the first button covers
     btn3 = Button(text='World', size_hint=(.5, 1))
 
     The first button will be 200px wide as specified, the second and third
-    will be 300px each, ie (800-200)*0.5
+    will be 300px each, e.g., (800-200)*0.5
 
 '''
 
@@ -82,13 +82,13 @@ class BoxLayout(Layout):
     def __init__(self, **kwargs):
         super(BoxLayout, self).__init__(**kwargs)
         self.bind(
-            spacing = self._trigger_layout,
-            padding = self._trigger_layout,
-            children = self._trigger_layout,
-            orientation = self._trigger_layout,
-            parent = self._trigger_layout,
-            size = self._trigger_layout,
-            pos = self._trigger_layout)
+            spacing=self._trigger_layout,
+            padding=self._trigger_layout,
+            children=self._trigger_layout,
+            orientation=self._trigger_layout,
+            parent=self._trigger_layout,
+            size=self._trigger_layout,
+            pos=self._trigger_layout)
 
     def do_layout(self, *largs):
         # optimize layout by preventing looking at the same attribute in a loop
