@@ -2,7 +2,7 @@
 Float Layout
 ============
 
-The :class:`FloatLayout` class will just honor the :data:`Widget.pos_hint` and
+The :class:`FloatLayout` class will only honor the :data:`Widget.pos_hint` and
 :data:`Widget.size_hint` attributes.
 
 .. only:: html
@@ -15,41 +15,40 @@ The :class:`FloatLayout` class will just honor the :data:`Widget.pos_hint` and
     .. image:: images/floatlayout.png
         :align: right
 
-For example, if you create a FloatLayout with size of (300, 300)::
+For example, if you create a FloatLayout with size a of (300, 300)::
 
     layout = FloatLayout(size=(300, 300))
 
-    # By default, all widgets have size_hint=(1, 1)
-    # So this button will have the same size as
-    # the layout
+By default, all widgets have size_hint=(1, 1), so this button will have the
+same size as the layout::
+
     button = Button(text='Hello world')
     layout.add_widget(button)
 
-    # To create a button of 50% width and 25%
-    # height of the layout and positioned at
-    # 20, 20, you can do
+To create a button of 50% width and 25% height of the layout and positioned at
+(20, 20), you can do::
+
     button = Button(
         text='Hello world',
         size_hint=(.5, .25),
         pos=(20, 20))
 
-::
+If you want to create a button that will always be the size of layout minus
+20% on each side::
 
-    # If you want to create a button that will always be the size of layout -
-    # 20% each sides
     button = Button(text='Hello world', size_hint=(.6, .6),
                     pos_hint={'x':.2, 'y':.2})
 
 .. note::
 
-    This layout can be used to start an application. Most of time, you need to
-    want which size is your Window.
+    This layout can be used for an application. Most of time, you will
+    use the size of Window.
 
 .. warning::
 
-    If you are not using pos_hint, you must handle yourself the position of your
-    childs. Mean if the float layout is moving, your must handle the moving
-    childs too.
+    If you are not using pos_hint, you must handle the position of
+    children: If the float layout is moving, you must handle moving
+    children too.
 
 '''
 
@@ -66,11 +65,11 @@ class FloatLayout(Layout):
         kwargs.setdefault('size', (1, 1))
         super(FloatLayout, self).__init__(**kwargs)
         self.bind(
-            children = self._trigger_layout,
-            pos = self._trigger_layout,
-            pos_hint = self._trigger_layout,
-            size_hint = self._trigger_layout,
-            size = self._trigger_layout)
+            children=self._trigger_layout,
+            pos=self._trigger_layout,
+            pos_hint=self._trigger_layout,
+            size_hint=self._trigger_layout,
+            size=self._trigger_layout)
 
     def do_layout(self, *largs):
         # optimization, until the size is 1, 1, don't do layout
@@ -95,10 +94,14 @@ class FloatLayout(Layout):
                     c.x = x + value * w
                 elif key == 'right':
                     c.right = x + value * w
+                elif key == 'pos':
+                    c.pos = x + value[0] * w, y + value[1] * h
                 elif key == 'y':
                     c.y = y + value * h
                 elif key == 'top':
                     c.top = y + value * h
+                elif key == 'center':
+                    c.center = x + value[0] * w, y + value[1] * h
                 elif key == 'center_x':
                     c.center_x = x + value * w
                 elif key == 'center_y':
@@ -106,16 +109,16 @@ class FloatLayout(Layout):
 
     def add_widget(self, widget, index=0):
         widget.bind(
-            size = self._trigger_layout,
-            size_hint = self._trigger_layout,
-            pos = self._trigger_layout,
-            pos_hint = self._trigger_layout)
+            size=self._trigger_layout,
+            size_hint=self._trigger_layout,
+            pos=self._trigger_layout,
+            pos_hint=self._trigger_layout)
         return super(Layout, self).add_widget(widget, index)
 
     def remove_widget(self, widget):
         widget.unbind(
-            size = self._trigger_layout,
-            size_hint = self._trigger_layout,
-            pos = self._trigger_layout,
-            pos_hint = self._trigger_layout)
+            size=self._trigger_layout,
+            size_hint=self._trigger_layout,
+            pos=self._trigger_layout,
+            pos_hint=self._trigger_layout)
         return super(Layout, self).remove_widget(widget)
