@@ -64,7 +64,7 @@ class StackLayout(Layout):
     '''
 
     minimum_width = NumericProperty(0)
-    '''Minimum width needed to contain all childrens.
+    '''Minimum width needed to contain all children.
 
     .. versionadded:: 1.0.8
 
@@ -73,7 +73,7 @@ class StackLayout(Layout):
     '''
 
     minimum_height = NumericProperty(0)
-    '''Minimum height needed to contain all childrens.
+    '''Minimum height needed to contain all children.
 
     .. versionadded:: 1.0.8
 
@@ -82,7 +82,7 @@ class StackLayout(Layout):
     '''
 
     minimum_size = ReferenceListProperty(minimum_width, minimum_height)
-    '''Minimum size needed to contain all childrens.
+    '''Minimum size needed to contain all children.
 
     .. versionadded:: 1.0.8
 
@@ -93,12 +93,12 @@ class StackLayout(Layout):
     def __init__(self, **kwargs):
         super(StackLayout, self).__init__(**kwargs)
         self.bind(
-            padding = self._trigger_layout,
-            spacing = self._trigger_layout,
-            children = self._trigger_layout,
-            orientation = self._trigger_layout,
-            size = self._trigger_layout,
-            pos = self._trigger_layout)
+            padding=self._trigger_layout,
+            spacing=self._trigger_layout,
+            children=self._trigger_layout,
+            orientation=self._trigger_layout,
+            size=self._trigger_layout,
+            pos=self._trigger_layout)
 
     def do_layout(self, *largs):
         # optimize layout by preventing looking at the same attribute in a loop
