@@ -30,7 +30,7 @@ To create a multiline textinput ('enter' key adds a new line)::
     textinput = TextInput(text='Hello world')
 
 To create a monoline textinput, set the multiline property to false ('enter'
-key will defocus the textinput and emit on_text_validate event) ::
+key will defocus the textinput and emit on_text_validate event)::
 
     def on_enter(instance, value):
         print 'User pressed enter in', instance
@@ -38,7 +38,7 @@ key will defocus the textinput and emit on_text_validate event) ::
     textinput = TextInput(text='Hello world', multiline=False)
     textinput.bind(on_text_validate=on_enter)
 
-To run a callback when the text changes ::
+To run a callback when the text changes::
 
     def on_text(instance, value):
         print 'The widget', instance, 'have:', value
@@ -47,13 +47,13 @@ To run a callback when the text changes ::
     textinput.bind(text=on_text)
 
 You can 'focus' a textinput, meaning that the input box will be highlighted,
-and keyboard will be requested ::
+and keyboard focus will be requested::
 
     textinput = TextInput(focus=True)
 
 The textinput is defocused if the 'escape' key is pressed, or if another
-widget requests the keyboard. You can bind a callback to focus property to
-get notified of focus changes ::
+widget requests the keyboard. You can bind a callback to the focus property to
+get notified of focus changes::
 
     def on_focus(instance, value):
         if value:
@@ -105,6 +105,8 @@ __all__ = ('TextInput', )
 
 import sys
 
+from os import environ
+from weakref import ref
 from functools import partial
 from kivy.logger import Logger
 from kivy.utils import boundary
@@ -126,6 +128,25 @@ FL_IS_NEWLINE = 0x01
 # late binding
 Clipboard = None
 
+# for reloading, we need to keep a list of textinput to retrigger the rendering
+_textinput_list = []
+
+
+# register an observer to clear the textinput cache when OpenGL will reload
+if 'KIVY_DOC' not in environ:
+
+    def _textinput_clear_cache(*l):
+        Cache.remove('textinput.label')
+        for wr in _textinput_list[:]:
+            textinput = wr()
+            if textinput is None:
+                _textinput_list.remove(wr)
+            else:
+                textinput._trigger_refresh_text()
+
+    from kivy.graphics.context import get_context
+    get_context().add_reload_observer(_textinput_clear_cache, True)
+
 
 class TextInputCutCopyPaste(Bubble):
     # Internal class used for showing the little bubble popup when
@@ -133,6 +154,23 @@ class TextInputCutCopyPaste(Bubble):
 
     textinput = ObjectProperty(None)
 
+    def __init__(self, **kwargs):
+        super(TextInputCutCopyPaste, self).__init__(**kwargs)
+        Clock.schedule_interval(self._check_parent, .5)
+
+    def _check_parent(self, dt):
+        # this is a prevention to get the Bubble staying on the screen, if the
+        # attached textinput is not on the screen anymore.
+        parent = self.textinput
+        while parent is not None:
+            if parent == parent.parent:
+                break
+            parent = parent.parent
+        if parent is None:
+            Clock.unschedule(self._check_parent)
+            if self.textinput:
+                self.textinput._hide_cut_copy_paste()
+
     def do(self, action):
         textinput = self.textinput
 
@@ -145,7 +183,7 @@ class TextInputCutCopyPaste(Bubble):
 
 
 class TextInput(Widget):
-    '''TextInput class, see module documentation for more information.
+    '''TextInput class. See module documentation for more information.
 
     :Events:
         `on_text_validate`
@@ -161,8 +199,8 @@ class TextInput(Widget):
         self._selection_finished = True
         self._selection_touch = None
         self.selection_text = ''
-        self.selection_from = None
-        self.selection_to = None
+        self.__selection_from = None
+        self._selection_to = None
         self._bubble = None
         self._lines_flags = []
         self._lines_labels = []
@@ -207,6 +245,9 @@ class TextInput(Widget):
         self._trigger_refresh_line_options()
         self._trigger_refresh_text()
 
+        # when the gl context is reloaded, trigger the text rendering again.
+        _textinput_list.append(ref(self, TextInput._reload_remove_observer))
+
     def on_text_validate(self):
         pass
 
@@ -232,7 +273,7 @@ class TextInput(Widget):
             return 0
 
     def cursor_offset(self):
-        '''Get the cursor x offset on the current line
+        '''Get the cursor x offset on the current line.
         '''
         offset = 0
         if self.cursor_col:
@@ -241,7 +282,7 @@ class TextInput(Widget):
         return offset
 
     def get_cursor_from_index(self, index):
-        '''Return the (row, col) of the cursor from text index
+        '''Return the (row, col) of the cursor from text index.
         '''
         index = boundary(index, 0, len(self.text))
         if index <= 0:
@@ -259,8 +300,27 @@ class TextInput(Widget):
             i = ni
         return index, row
 
-    def insert_text(self, substring, from_undo = False):
-        '''Insert new text on the current cursor position
+    def select_text(self, start, end):
+        ''' Select portion of text displayed in this TextInput
+
+        .. versionadded:: 1.4.0
+        '''
+        if end < start:
+            raise Exception('end must be superior to start')
+        m = len(self.text)
+        self._selection_from = boundary(start, 0, m)
+        self._selection_to = boundary(end, 0, m)
+        self._update_selection(True)
+
+    def select_all(self):
+        ''' Select all of the text displayed in this TextInput
+
+        .. versionadded:: 1.4.0
+        '''
+        self.select_text(0, len(self.text))
+
+    def insert_text(self, substring, from_undo=False):
+        '''Insert new text on the current cursor position.
         '''
         if self.readonly:
             return
@@ -291,19 +351,13 @@ class TextInput(Widget):
         elif count > 0:
             cursor = cursor[0], cursor[1] + count
 
-        self._undo.append({'undo_command': \
-            'self.cursor = (%i, %i)\n' %(cursor[0], cursor[1]) +\
-            'self.selection_from = %i\nself.selection_to = %i\n' %(ci, sci())+
-            'self._selection = True\n'+\
-            'self.delete_selection(True)\n',\
-            'redo_command': \
-            'self.cursor = (%i, %i)\nself.insert_text(u\'%s\', True)'\
-            %(cc, cr, substring.replace('\n', '\\n').replace('\'', '\\\''))})
+        self._undo.append({'undo_command': ('insert', cursor, ci, sci()),
+            'redo_command': (cc, cr, substring)})
         #reset redo when undo is appended to
         self._redo = []
 
     def reset_undo(self):
-        '''Reset undo and redo lists from memory
+        '''Reset undo and redo lists from memory.
 
         .. versionadded:: 1.3.0
 
@@ -316,12 +370,29 @@ class TextInput(Widget):
         .. versionadded:: 1.3.0
 
         This action re-does any command that has been un-done by do_undo/ctrl+z.
-        This function is automaticlly called when `ctrl+r` keys
-        are pressed.
+        This function is automaticlly called when `ctrl+r` keys are pressed.
         '''
         try:
             x_item = self._redo.pop()
-            exec(x_item['redo_command'])
+            undo_type = x_item['undo_command'][0]
+
+            if undo_type == 'insert':
+                cc, cr, substring = x_item['redo_command']
+                self.cursor = cc, cr
+                self.insert_text(substring, True)
+                #substring.replace('\n', '\\n').replace('\'', '\\\'')
+            elif undo_type == 'bkspc':
+                cc, cr = x_item['redo_command']
+                self.cursor = cc, cr
+                self.do_backspace(True)
+            else:
+                # delsel
+                ci, sci, cc, cr = x_item['redo_command']
+                self._selection_from = ci
+                self._selection_to = sci
+                self._selection = True
+                self.delete_selection(True)
+                self.cursor = (cc, cr)
             self._undo.append(x_item)
         except IndexError:
             # reached at top of undo list
@@ -334,20 +405,34 @@ class TextInput(Widget):
 
         This action un-does any edits that have been made since the last
         call to reset_undo().
-        This function is automatically called when `ctrl+z` keys
-        are pressed.
+        This function is automatically called when `ctrl+z` keys are pressed.
         '''
         try:
             x_item = self._undo.pop()
-            exec(x_item['undo_command'])
+            undo_type = x_item['undo_command'][0]
+            self.cursor = x_item['undo_command'][1]
+
+            if undo_type == 'insert':
+                ci, sci = x_item['undo_command'][2:]
+                self._selection_from = ci
+                self._selection_to = sci
+                self._selection = True
+                self.delete_selection(True)
+            elif undo_type == 'bkspc':
+                substring = x_item['undo_command'][2:]
+                self.insert_text(substring, True)
+            else:
+                # delsel
+                substring = x_item['undo_command'][2:][0]
+                self.insert_text(substring, True)
             self._redo.append(x_item)
         except IndexError:
             # reached at top of undo list
             pass
 
-    def do_backspace(self, from_undo = False):
+    def do_backspace(self, from_undo=False):
         '''Do backspace operation from the current cursor position.
-        This action might do lot of things like:
+        This action might do several things:
 
             - removing the current selection if available
             - removing the previous char, and back the cursor
@@ -368,8 +453,8 @@ class TextInput(Widget):
             substring = '\n'
         else:
             #ch = text[cc-1]
-            substring = text[cc-1]
-            new_text = text[:cc-1] + text[cc:]
+            substring = text[cc - 1]
+            new_text = text[:cc - 1] + text[cc:]
             self._set_line_text(cr, new_text)
 
         # refresh_text seems to be unnecessary here
@@ -385,13 +470,9 @@ class TextInput(Widget):
         if from_undo:
             return
 
-        self._undo.append({'undo_command': \
-            'self.cursor = (%i, %i)\n' %(cursor[0], cursor[1]) +\
-            'self.insert_text(u\'%s\', True)'\
-            %(substring.replace('\n', '\\n').replace('\'', '\\\'')),
-            'redo_command': \
-            'self.cursor = (%i, %i)\n' %(cc, cr)+\
-            'self.do_backspace(True)'})
+        self._undo.append({
+            'undo_command': ('bkspc', cursor, substring),
+            'redo_command': (cc, cr)})
         #reset redo when undo is appended to
         self._redo = []
 
@@ -410,7 +491,7 @@ class TextInput(Widget):
 
         .. warning::
 
-            Current page are 3 lines before/after
+            Current page has three lines before/after.
 
         '''
         pgmove_speed = 3
@@ -445,11 +526,11 @@ class TextInput(Widget):
         dy = self.line_height + self._line_spacing
         cx = x - self.x
         scrl_y = self.scroll_y
-        scrl_y = scrl_y/ dy if scrl_y > 0 else 0
+        scrl_y = scrl_y / dy if scrl_y > 0 else 0
         cy = (self.top - self.padding_y + scrl_y * dy) - y
         cy = int(boundary(round(cy / dy), 0, len(l) - 1))
         dcx = 0
-        for i in xrange(1, len(l[cy])+1):
+        for i in xrange(1, len(l[cy]) + 1):
             if self._get_text_width(l[cy][:i]) >= cx:
                 break
             dcx = i
@@ -460,27 +541,27 @@ class TextInput(Widget):
     # Selection control
     #
     def cancel_selection(self):
-        '''Cancel current selection (if any)
+        '''Cancel current selection (if any).
         '''
         self._selection = False
         self._selection_finished = True
         self._selection_touch = None
         self._trigger_update_graphics()
 
-    def delete_selection(self, from_undo = False):
-        '''Delete the current text selection (if any)
+    def delete_selection(self, from_undo=False):
+        '''Delete the current text selection (if any).
         '''
         if self.readonly:
             return
         scrl_x = self.scroll_x
         scrl_y = self.scroll_y
         cc, cr = self.cursor
-        sci = self.cursor_index
-        ci = sci()
+        #sci = self.cursor_index
+        #ci = sci()
         if not self._selection:
             return
         v = self.text
-        a, b = self.selection_from, self.selection_to
+        a, b = self._selection_from, self._selection_to
         if a > b:
             a, b = b, a
         text = v[:a] + v[b:]
@@ -498,23 +579,17 @@ class TextInput(Widget):
         if from_undo:
             return
 
-        self._undo.append({'undo_command': \
-            'self.cursor = (%i, %i)\n' %(cursor[0], cursor[1]) +\
-            'self.insert_text(u\'%s\', True)'\
-            %(substring.replace('\n', '\\n').replace('\'', '\\\'')),
-            'redo_command': \
-            'self.selection_from = %i\nself.selection_to = %i\n' %(ci, sci)+
-            'self._selection = True\n'+\
-            'self.delete_selection(True)\n'+\
-            'self.cursor = (%i, %i)\n' %(cc, cr)})
+        self._undo.append({
+            'undo_command': ('delsel', cursor, substring),
+            'redo_command': (ci, sci, cc, cr)})
         #reset redo when undo is appended to
         self._redo = []
 
     def _update_selection(self, finished=False):
         '''Update selection text and order of from/to if finished is True.
-        Can be called multiple times until finished=True.
+        Can be called multiple times until finished is True.
         '''
-        a, b = self.selection_from, self.selection_to
+        a, b = self._selection_from, self._selection_to
         if a > b:
             a, b = b, a
         self._selection_finished = finished
@@ -543,7 +618,7 @@ class TextInput(Widget):
         if not self._selection_touch:
             self.cancel_selection()
             self._selection_touch = touch
-            self.selection_from = self.selection_to = self.cursor_index()
+            self._selection_from = self._selection_to = self.cursor_index()
             self._update_selection()
         return True
 
@@ -557,7 +632,7 @@ class TextInput(Widget):
             return False
         if self._selection_touch is touch:
             self.cursor = self.get_cursor_from_xy(touch.x, touch.y)
-            self.selection_to = self.cursor_index()
+            self._selection_to = self.cursor_index()
             self._update_selection()
             return True
 
@@ -568,7 +643,7 @@ class TextInput(Widget):
         if not self.focus:
             return False
         if self._selection_touch is touch:
-            self.selection_to = self.cursor_index()
+            self._selection_to = self.cursor_index()
             self._update_selection(True)
             # show Bubble
             win = self._win
@@ -578,18 +653,21 @@ class TextInput(Widget):
                 Logger.warning('Textinput: '
                     'Cannot show bubble, unable to get root window')
                 return True
-            if self.selection_to != self.selection_from:
+            if self._selection_to != self._selection_from:
                 self._show_cut_copy_paste(touch.pos, win)
             else:
                 self._hide_cut_copy_paste(win)
             return True
 
-    def _hide_cut_copy_paste(self, win):
+    def _hide_cut_copy_paste(self, win=None):
+        win = win or self._win
+        if win is None:
+            return
         bubble = self._bubble
         if bubble is not None:
             win.remove_widget(bubble)
 
-    def _show_cut_copy_paste(self, pos, win, parent_changed = False, *l):
+    def _show_cut_copy_paste(self, pos, win, parent_changed=False, *l):
         # Show a bubble with cut copy and paste buttons
         bubble = self._bubble
         if bubble is None:
@@ -615,7 +693,7 @@ class TextInput(Widget):
         # FIXME found a way to have that feature available for everybody
         if bubble_pos[0] < 0:
             # bubble beyond left of window
-            if bubble.pos[1] > (win_size[1]- bubble_size[1]):
+            if bubble.pos[1] > (win_size[1] - bubble_size[1]):
                 # bubble above window height
                 bubble.pos = (0, (t_pos[1]) - (bubble_size[1] + lh + ls))
                 bubble.arrow_pos = 'top_left'
@@ -624,7 +702,7 @@ class TextInput(Widget):
                 bubble.arrow_pos = 'bottom_left'
         elif bubble.right > win_size[0]:
             # bubble beyond right of window
-            if bubble_pos[1] > (win_size[1]- bubble_size[1]):
+            if bubble_pos[1] > (win_size[1] - bubble_size[1]):
                 # bubble above window height
                 bubble.pos = (win_size[0] - bubble_size[0],
                         (t_pos[1]) - (bubble_size[1] + lh + ls))
@@ -633,7 +711,7 @@ class TextInput(Widget):
                 bubble.right = win_size[0]
                 bubble.arrow_pos = 'bottom_right'
         else:
-            if bubble_pos[1] > (win_size[1]- bubble_size[1]):
+            if bubble_pos[1] > (win_size[1] - bubble_size[1]):
                 # bubble above window height
                 bubble.pos = (bubble_pos[0],
                         (t_pos[1]) - (bubble_size[1] + lh + ls))
@@ -646,6 +724,13 @@ class TextInput(Widget):
     #
     # Private
     #
+
+    @staticmethod
+    def _reload_remove_observer(wr):
+        # called when the textinput is deleted
+        if wr in _textinput_list:
+            _textinput_list.remove(wr)
+
     def on_focus(self, instance, value, *largs):
         win = self._win
         if not win:
@@ -688,6 +773,7 @@ class TextInput(Widget):
             return
         if Clipboard is None:
             from kivy.core.clipboard import Clipboard
+            Clipboard
         _platform = platform()
         if _platform == 'win':
             self._clip_mime_type = 'text/plain;charset=utf-8'
@@ -795,8 +881,8 @@ class TextInput(Widget):
         _create_label = self._create_line_label
         _lines_labels = self._lines_labels =\
             [_create_label(x) for x in _lines]
-        self._lines_rects = [Rectangle(texture=x, size=( \
-                             x.size if x else (0, 0))) \
+        self._lines_rects = [Rectangle(texture=x, size=(
+                             x.size if x else (0, 0)))
                              for x in _lines_labels]
         line_label = _lines_labels[0]
         if line_label is None:
@@ -890,7 +976,15 @@ class TextInput(Widget):
                     tch = (vh / float(lh)) * oh
                     size[1] = vh
 
-                texc = (tcx, tcy+tch, tcx+tcw, tcy+tch, tcx+tcw, tcy, tcx, tcy)
+                texc = (
+                        tcx,
+                        tcy + tch,
+                        tcx + tcw,
+                        tcy + tch,
+                        tcx + tcw,
+                        tcy,
+                        tcx,
+                        tcy)
 
                 # add rectangle.
                 r = rects[line_num]
@@ -916,8 +1010,8 @@ class TextInput(Widget):
         miny = self.y + _padding_y
         maxy = _top - _padding_y
         draw_selection = self._draw_selection
-        scroll_y = self.scroll_y
-        a, b = self.selection_from, self.selection_to
+        #scroll_y = self.scroll_y
+        a, b = self._selection_from, self._selection_to
         if a > b:
             a, b = b, a
         get_cursor_from_index = self.get_cursor_from_index
@@ -935,7 +1029,7 @@ class TextInput(Widget):
 
     def _draw_selection(self, pos, size, line_num):
         # Draw the current selection on the widget.
-        a, b = self.selection_from, self.selection_to
+        a, b = self._selection_from, self._selection_to
         if a > b:
             a, b = b, a
         get_cursor_from_index = self.get_cursor_from_index
@@ -1044,8 +1138,8 @@ class TextInput(Widget):
                 continue
             if oldindex != index:
                 yield text[oldindex:index]
-            yield text[index:index+1]
-            oldindex = index+1
+            yield text[index:index + 1]
+            oldindex = index + 1
         yield text[oldindex:]
 
     def _split_smart(self, text):
@@ -1099,13 +1193,13 @@ class TextInput(Widget):
             self.insert_text(displayed_str)
         elif internal_action in ('shift', 'shift_L', 'shift_R'):
             if not self._selection:
-                self.selection_from = self.selection_to = self.cursor_index()
+                self._selection_from = self._selection_to = self.cursor_index()
                 self._selection = True
             self._selection_finished = False
         elif internal_action.startswith('cursor_'):
             self.do_cursor_movement(internal_action)
             if self._selection and not self._selection_finished:
-                self.selection_to = self.cursor_index()
+                self._selection_to = self.cursor_index()
                 self._update_selection()
             else:
                 self.cancel_selection()
@@ -1147,19 +1241,17 @@ class TextInput(Widget):
         if text and not key in (self.interesting_keys.keys() + [27]):
             # This allows *either* ctrl *or* cmd, but not both.
             if modifiers == ['ctrl'] or (is_osx and modifiers == ['meta']):
-                if key == ord('x'): # cut selection
+                if key == ord('x'):  # cut selection
                     self._cut(self.selection_text)
-                elif key == ord('c'): # copy selection
+                elif key == ord('c'):  # copy selection
                     self._copy(self.selection_text)
-                elif key == ord('v'): # paste selection
+                elif key == ord('v'):  # paste selection
                     self._paste()
-                elif key == ord('a'): # select all
-                    self.selection_from = 0
-                    self.selection_to = len(self.text)
-                    self._update_selection(True)
-                elif key == ord('z'): # undo
+                elif key == ord('a'):  # select all
+                    self.select_all()
+                elif key == ord('z'):  # undo
                     self.do_undo()
-                elif key == ord('r'): # redo
+                elif key == ord('r'):  # redo
                     self.do_redo()
             else:
                 if self._selection:
@@ -1168,10 +1260,10 @@ class TextInput(Widget):
             #self._recalc_size()
             return
 
-        if key == 27: # escape
+        if key == 27:  # escape
             self.focus = False
             return True
-        elif key == 9: # tab
+        elif key == 9:  # tab
             self.insert_text('\t')
             return True
 
@@ -1203,7 +1295,7 @@ class TextInput(Widget):
     '''
 
     multiline = BooleanProperty(True)
-    '''If True, the widget will be able show multiple lines of text. If false,
+    '''If True, the widget will be able show multiple lines of text. If False,
     "enter" action will defocus the textinput instead of adding a new line.
 
     :data:`multiline` is a :class:`~kivy.properties.BooleanProperty`, default to
@@ -1211,7 +1303,7 @@ class TextInput(Widget):
     '''
 
     password = BooleanProperty(False)
-    '''If True, the widget will display its characters as the character*.
+    '''If True, the widget will display its characters as the character '*'.
 
     .. versionadded:: 1.2.0
 
@@ -1221,7 +1313,7 @@ class TextInput(Widget):
 
     cursor_blink = BooleanProperty(False)
     '''This property is used to blink the cursor graphics. The value of
-    :data:`cursor_blink` is automatically computed, setting a value on it will
+    :data:`cursor_blink` is automatically computed. Setting a value on it will
     have no impact.
 
     :data:`cursor_blink` is a :class:`~kivy.properties.BooleanProperty`, default
@@ -1317,7 +1409,7 @@ class TextInput(Widget):
     '''
 
     tab_width = NumericProperty(4)
-    '''By default, each tab will be replaced by the size of 4 spaces on the text
+    '''By default, each tab will be replaced by four spaces on the text
     input widget. You can set a lower or higher value.
 
     :data:`tab_width` is a :class:`~kivy.properties.NumericProperty`, default to
@@ -1339,7 +1431,7 @@ class TextInput(Widget):
     '''
 
     padding = ReferenceListProperty(padding_x, padding_y)
-    '''Padding of the text, in the format (padding_x, padding_y)
+    '''Padding of the text, in the format (padding_x, padding_y).
 
     :data:`padding` is a :class:`~kivy.properties.ReferenceListProperty` of
     (:data:`padding_x`, :data:`padding_y`) properties.
@@ -1347,8 +1439,8 @@ class TextInput(Widget):
 
     scroll_x = NumericProperty(0)
     '''X scrolling value of the viewport. The scrolling is automatically updated
-    when the cursor is moving or text is changing. If you are not doing any
-    action, you can still change the scroll_x and scroll_y properties.
+    when the cursor is moving or text is changing. If there is no action, the
+    scroll_x and scroll_y properties may be changed.
 
     :data:`scroll_x` is a :class:`~kivy.properties.NumericProperty`, default to
     0.
@@ -1368,7 +1460,7 @@ class TextInput(Widget):
     .. warning::
 
         The color should always have "alpha" component different from 1, since
-        the selection is drawed after the text.
+        the selection is drawn after the text.
 
     :data:`selection_color` is a :class:`~kivy.properties.ListProperty`, default
     to [0.1843, 0.6549, 0.8313, .5]
@@ -1392,31 +1484,41 @@ class TextInput(Widget):
     default to [0, 0, 0, 1] #Black
     '''
 
-    selection_from = NumericProperty(None, allownone=True)
-    '''If a selection is happening, or finished, this property will represent
-    the cursor index where the selection start.
+    def get_sel_from(self):
+        return self._selection_from
 
-    :data:`selection_from` is a :class:`~kivy.properties.NumericProperty`,
-    default to None
+    selection_from = AliasProperty(get_sel_from, None)
+    '''If a selection is happening, or finished, this property will represent
+    the cursor index where the selection started.
+
+    .. versionchanged:: 1.4.0
+
+    :data:`selection_from` is a :class:`~kivy.properties.AliasProperty`,
+    default to None, readonly.
     '''
 
-    selection_to = NumericProperty(None, allownone=True)
-    '''If a selection is happening, or finished, this property will represent
-    the cursor index where the selection end.
+    def get_sel_to(self):
+        return self._selection_to
 
-    :data:`selection_to` is a :class:`~kivy.properties.NumericProperty`,
-    default to None
+    selection_to = AliasProperty(get_sel_to, None)
+    '''If a selection is happening, or finished, this property will represent
+    the cursor index where the selection started.
+
+    .. versionchanged:: 1.4.0
+
+    :data:`selection_to` is a :class:`~kivy.properties.AliasProperty`,
+    default to None, readonly.
     '''
 
     selection_text = StringProperty('')
     '''Current content selection.
 
     :data:`selection_text` is a :class:`~kivy.properties.StringProperty`,
-    default to ''
+    default to '', readonly.
     '''
 
     focus = BooleanProperty(False)
-    '''If focus is true, the keyboard will be requested, and you can start to
+    '''If focus is True, the keyboard will be requested, and you can start to
     write on the textinput.
 
     :data:`focus` is a :class:`~kivy.properties.BooleanProperty`, default to
@@ -1426,7 +1528,7 @@ class TextInput(Widget):
     def _get_text(self):
         lf = self._lines_flags
         l = self._lines
-        text = ''.join([('\n' if (lf[i] & FL_IS_NEWLINE) else '') + l[i] \
+        text = ''.join([('\n' if (lf[i] & FL_IS_NEWLINE) else '') + l[i]
                         for i in xrange(len(l))])
         return text
 
@@ -1439,11 +1541,11 @@ class TextInput(Widget):
     text = AliasProperty(_get_text, _set_text, bind=('_lines', ))
     '''Text of the widget.
 
-    Creation of a simple hello world ::
+    Creation of a simple hello world::
 
         widget = TextInput(text='Hello world')
 
-    If you want to create the widget with an unicode string, use ::
+    If you want to create the widget with an unicode string, use::
 
         widget = TextInput(text=u'My unicode string')
 
@@ -1451,19 +1553,19 @@ class TextInput(Widget):
     '''
 
     font_name = StringProperty('DroidSans')
-    '''Filename of the font to use, the path can be absolute or relative.
+    '''Filename of the font to use. The path can be absolute or relative.
     Relative paths are resolved by the :func:`~kivy.resources.resource_find`
     function.
 
     .. warning::
 
-        Depending of your text provider, the font file can be ignored. However
+        Depending on your text provider, the font file can be ignored. However,
         you can mostly use this without trouble.
 
-        If the font used lacks the glyphs for the perticular language/symbols
+        If the font used lacks the glyphs for the particular language/symbols
         you are using, you will see '[]' blank box characters instead of the
         actual glyphs. The solution is to use a font that has the glyphs you
-        need to display. For example to display |unicodechar|, use a font like
+        need to display. For example, to display |unicodechar|, use a font like
         freesans.ttf that has the glyph.
 
         .. |unicodechar| image:: images/unicode-char.png
@@ -1479,6 +1581,7 @@ class TextInput(Widget):
     10.
     '''
 
+
 if __name__ == '__main__':
     from kivy.app import App
     from kivy.uix.boxlayout import BoxLayout
