@@ -9,63 +9,98 @@ Tree View
     This widget is still experimental, and his API is subject to change in a
     future version.
 
-:class:`TreeView` is a widget to represent tree list. It's currently very basic,
-but support the minimal features set to be usable.
+:class:`TreeView` is a widget to represent a tree structure. It's currently
+very basic, supporting a minimal feature set.
 
-Introduction to the TreeView
-----------------------------
+Introduction
+------------
 
-A :class:`TreeView` is populated with :class:`TreeViewNode`, but you cannot use
-directly a :class:`TreeViewNode`. You must combine it with another widget, such
-as :class:`~kivy.uix.label.Label`, :class:`~kivy.uix.button.Button`... or even
-your own widget. The TreeView always create a default root node, based on
-:class:`TreeViewLabel`.
+A :class:`TreeView` is populated with :class:`TreeViewNode` instances, but you
+cannot use a :class:`TreeViewNode` directly. You must combine it with another
+widget, such as :class:`~kivy.uix.label.Label`,
+:class:`~kivy.uix.button.Button`... or even your own widget. The TreeView
+always creates a default root node, based on :class:`TreeViewLabel`.
 
-The :class:`TreeViewNode` is just an class object that hold the needed property
-to successful use the other class as a node for the Tree. You can read the next
-section about how to create custom node to be used in the :class:`TreeView`.
+:class:`TreeViewNode` is a class object containing needed properties for
+serving as a tree node. Extend TreeViewNode to create custom a custom node
+type for use with :class:`TreeView`.
 
-For you, we have combine Label + TreeViewNode: the result is a
-:class:`TreeViewLabel`, that you can directly use as a node in the Tree.
+For constructing your own subclass, follow the pattern of TreeViewLabel, which
+combines Label and TreeViewNode, producing :class:`TreeViewLabel` for direct
+use in a TreeView instance.
 
-For example, you can create 2 nodes, directly attached to root::
+To use the TreeViewLabel class, you could create two nodes, directly attached
+to root::
 
     tv = TreeView()
     tv.add_node(TreeViewLabel(text='My first item'))
     tv.add_node(TreeViewLabel(text='My second item'))
 
-If you want to create 2 nodes attached to another one, you can do::
+Or, create two nodes attached to a first::
 
     tv = TreeView()
     n1 = tv.add_node(TreeViewLabel(text='Item 1'))
     tv.add_node(TreeViewLabel(text='SubItem 1'), n1)
     tv.add_node(TreeViewLabel(text='SubItem 2'), n1)
 
-The default root widget is always opened, and have a default text 'Root'. If you
-want to change that, you can use :data:`TreeView.root_options` property. This
-will pass options to the root widget::
+If you have a large tree structure, perhaps you would need a utility function
+to populate the tree view, as with::
+
+    def populate_tree_view(tree_view, parent, node):
+        if parent is None:
+            tree_node = tree_view.add_node(TreeNodeLabel(text=node['node_id'],
+                                                         is_open=True))
+        else:
+            tree_node = tree_view.add_node(TreeNodeLabel(text=node['node_id'],
+                                                         is_open=True), parent)
+
+        for child_node in node['children']:
+            populate_tree_view(tree_view, tree, child_node)
+
+    tree = {'node_id': '1',
+            'children': [{'node_id': '1.1',
+                          'children': [{'node_id': '1.1.1',
+                                        'children': [{'node_id': '1.1.1.1',
+                                                      'children': []}]},
+                                       {'node_id': '1.1.2',
+                                        'children': []},
+                                       {'node_id': '1.1.3',
+                                        'children': []}]},
+                          {'node_id': '1.2',
+                           'children': []}]}
+
+    tv = TreeView(root_options=dict(text='Tree One'),
+                  hide_root=False,
+                  indent_level=4)
+    populate_tree_view(tv, None, tree)
+    some_containing_widget.add_widget(tv)
+
+The root widget in the tree view is opened by default, and has a text set as
+'Root'. If you want to change that, you can use :data:`TreeView.root_options`
+property. This will pass options to the root widget::
 
     tv = TreeView(root_options=dict(text='My root label'))
 
 
-Create your own node widget
----------------------------
+Creating Your Own Node Widget
+-----------------------------
 
-If you want to create a button node for example, you can just combine
-:class:`~kivy.uix.button.Button` + :class:`TreeViewNode` like this::
+For a button node type, combine :class:`~kivy.uix.button.Button` +
+:class:`TreeViewNode` like this::
 
     class TreeViewButton(Button, TreeViewNode):
         pass
 
-You must know that only the :data:`~kivy.uix.widget.Widget.size_hint_x` will be
-honored. The allocated width will depend of the current width of the TreeView
-and the level of the node. For example, if your node is at level 4, the width
+You must know that, for a given node, only the
+:data:`~kivy.uix.widget.Widget.size_hint_x` will be honored. The allocated
+width for the node will depend of the current width of the TreeView and the
+level of the node. For example, if a node is at level 4, the width
 allocated will be:
 
     treeview.width - treeview.indent_start - treeview.indent_level * node.level
 
-You might have some trouble with that, it's on your side to correctly handle
-that case, and adapt the graphical representation of your node if needed
+You might have some trouble with that. It is the developer's responsibility to
+correctly handle adapt the graphical representation nodes, if needed.
 '''
 
 from kivy.clock import Clock
@@ -76,7 +111,7 @@ from kivy.properties import BooleanProperty, ListProperty, ObjectProperty, \
 
 
 class TreeViewException(Exception):
-    '''Exception for errors in the :class:`TreeView`
+    '''Exception for errors in the :class:`TreeView`.
     '''
     pass
 
@@ -91,32 +126,32 @@ class TreeViewNode(object):
         super(TreeViewNode, self).__init__(**kwargs)
 
     is_leaf = BooleanProperty(True)
-    '''Boolean to indicate if this node is a leaf or not, used to adjust
+    '''Boolean to indicate if this node is a leaf or not. Used to adjust
     graphical representation.
 
-    :data:`is_leaf` is a :class:`~kivy.properties.BooleanProperty`, default to
+    :data:`is_leaf` is a :class:`~kivy.properties.BooleanProperty`, defaults to
     True, and automatically set to False when child is added.
     '''
 
     is_open = BooleanProperty(False)
-    '''Boolean to indicate if this node is opened or not, in case if he contain
-    children nodes. This is used for graphical representation.
+    '''Boolean to indicate if this node is opened or not, in case if there are
+    child nodes. This is used to adjust graphical representation.
 
     .. warning::
 
-        This property is automatically setted by the :class:`TreeView`. You can
-        read it but not write on it.
+        This property is automatically set by the :class:`TreeView`. You can
+        read but not write it.
 
-    :data:`is_open` is a :class:`~kivy.properties.BooleanProperty`, default to
+    :data:`is_open` is a :class:`~kivy.properties.BooleanProperty`, defaults to
     False.
     '''
 
     is_loaded = BooleanProperty(False)
     '''Boolean to indicate if this node is already loaded or not. This property
-    is used only if the :class:`TreeView` use asynchronous loading.
+    is used only if the :class:`TreeView` uses asynchronous loading.
 
-    :data:`is_loaded` is a :class:`~kivy.properties.BooleanProperty`, default to
-    False
+    :data:`is_loaded` is a :class:`~kivy.properties.BooleanProperty`, default
+    to False
     '''
 
     is_selected = BooleanProperty(False)
@@ -125,8 +160,8 @@ class TreeViewNode(object):
 
     .. warning::
 
-        This property is automatically setted by the :class:`TreeView`. You can
-        read it but not write on it.
+        This property is automatically set by the :class:`TreeView`. You can
+        read but not write it.
 
     :data:`is_selected` is a :class:`~kivy.properties.BooleanProperty`, default
     to False.
@@ -136,20 +171,20 @@ class TreeViewNode(object):
     '''Boolean to indicate if we allow selection of the node or not.
 
     :data:`no_selection` is a :class:`~kivy.properties.BooleanProperty`,
-    default to False
+    defaults to False
     '''
 
     nodes = ListProperty([])
-    '''List of nodes. The nodes list is differents than children. Nodes
-    represent a node on the tree, while children represent the widget associated
-    to the current node.
+    '''List of nodes. The nodes list is different than the children list. A
+    node in the nodes list represents a node on the tree. An item in the
+    children list represents the widget associated with the node.
 
     .. warning::
 
-        This property is automatically setted by the :class:`TreeView`. You can
-        read it, but not write on it.
+        This property is automatically set by the :class:`TreeView`. You can
+        read but not write it.
 
-    :data:`nodes` is a :class:`~kivy.properties.ListProperty`, default to [].
+    :data:`nodes` is a :class:`~kivy.properties.ListProperty`, defaults to [].
     '''
 
     parent_node = ObjectProperty(None, allownone=True)
@@ -165,14 +200,15 @@ class TreeViewNode(object):
     level = NumericProperty(-1)
     '''Level of the node.
 
-    :data:`level` is a :class:`~kivy.properties.NumericProperty`, default to -1.
+    :data:`level` is a :class:`~kivy.properties.NumericProperty`, defaults to
+    -1.
     '''
 
     color_selected = ListProperty([.3, .3, .3, 1.])
     '''Background color of the node when the node is selected.
 
-    :data:`color_selected` is a :class:`~kivy.properties.ListProperty`, defaults
-    to [.1, .1, .1, 1]
+    :data:`color_selected` is a :class:`~kivy.properties.ListProperty`,
+    defaults to [.1, .1, .1, 1]
     '''
 
     odd = BooleanProperty(False)
@@ -190,7 +226,7 @@ class TreeViewNode(object):
     '''
 
     even_color = ListProperty([0.5, 0.5, 0.5, 0.1])
-    '''Background color of odd nodes when the node is not selected.
+    '''Background color of even nodes when the node is not selected.
 
     :data:`bg_color` is a :class:`~kivy.properties.ListProperty`, default
     to [.5, .5, .5, .1].
@@ -211,7 +247,7 @@ class TreeView(Widget):
 
     :Events:
         `on_node_expand`: (node, )
-            Fired when a node is being expended
+            Fired when a node is being expanded
         `on_node_collapse`: (node, )
             Fired when a node is being collapsed
     '''
@@ -238,7 +274,7 @@ class TreeView(Widget):
         :Parameters:
             `node`: instance of a :class:`TreeViewNode`
                 Node to add into the tree
-            `parent`: instance of a :class:`TreeViewNode`, default to None
+            `parent`: instance of a :class:`TreeViewNode`, defaults to None
                 Parent node to attach the new node
         '''
         # check if the widget is "ok" for a node
@@ -287,7 +323,7 @@ class TreeView(Widget):
         pass
 
     def select_node(self, node):
-        '''Select a node in the tree
+        '''Select a node in the tree.
         '''
         if node.no_selection:
             return
@@ -297,7 +333,7 @@ class TreeView(Widget):
         self._selected_node = node
 
     def toggle_node(self, node):
-        '''Toggle the state of the node (open/collapse)
+        '''Toggle the state of the node (open/collapse).
         '''
         node.is_open = not node.is_open
         if node.is_open:
@@ -309,7 +345,7 @@ class TreeView(Widget):
         self._trigger_layout()
 
     def get_node_at_pos(self, pos):
-        '''Get a node a at the position (x, y).
+        '''Get a node at the position (x, y).
         '''
         x, y = pos
         for node in self.iterate_open_nodes(self.root):
@@ -319,8 +355,8 @@ class TreeView(Widget):
 
     def iterate_open_nodes(self, node=None):
         '''Generator to iterate over expanded nodes.
-        Example for get all the node opened:
-        ::
+
+        To get all the open nodes::
 
             treeview = TreeView()
             # ... add nodes ...
@@ -342,7 +378,7 @@ class TreeView(Widget):
                 yield ynode
 
     def iterate_all_nodes(self, node=None):
-        '''Generate to iterate over all nodes, expanded or not.
+        '''Generator to iterate over all nodes, expanded or not.
         '''
         if not node:
             node = self.root
@@ -447,30 +483,30 @@ class TreeView(Widget):
     #
 
     minimum_width = NumericProperty(0)
-    '''Minimum width needed to contain all childrens.
+    '''Minimum width needed to contain all children.
 
     .. versionadded:: 1.0.9
 
-    :data:`minimum_width` is a :class:`kivy.properties.NumericProperty`, default
-    to 0.
+    :data:`minimum_width` is a :class:`kivy.properties.NumericProperty`,
+    defaults to 0.
     '''
 
     minimum_height = NumericProperty(0)
-    '''Minimum height needed to contain all childrens.
+    '''Minimum height needed to contain all children.
 
     .. versionadded:: 1.0.9
 
     :data:`minimum_height` is a :class:`kivy.properties.NumericProperty`,
-    default to 0.
+    defaults to 0.
     '''
 
     minimum_size = ReferenceListProperty(minimum_width, minimum_height)
-    '''Minimum size needed to contain all childrens.
+    '''Minimum size needed to contain all children.
 
     .. versionadded:: 1.0.9
 
-    :data:`minimum_size` is a :class:`~kivy.properties.ReferenceListProperty` of
-    (:data:`minimum_width`, :data:`minimum_height`) properties.
+    :data:`minimum_size` is a :class:`~kivy.properties.ReferenceListProperty`
+    of (:data:`minimum_width`, :data:`minimum_height`) properties.
     '''
 
     indent_level = NumericProperty(16)
@@ -481,24 +517,25 @@ class TreeView(Widget):
         :data:`indent_start` + level * :data:`indent_level`
 
     :data:`indent_level` is a :class:`~kivy.properties.NumericProperty`,
-    default to 16.
+    defaults to 16.
     '''
 
     indent_start = NumericProperty(24)
     '''Indentation width of the level 0 / root node. This is mostly the initial
-    size to put an tree icon (collapsed / expanded). See :data:`indent_level`
-    for more information about the computation of level indentation.
+    size to accommodate a tree icon (collapsed / expanded). See
+    :data:`indent_level` for more information about the computation of level
+    indentation.
 
     :data:`indent_start` is a :class:`~kivy.properties.NumericProperty`,
-    default to 24.
+    defaults to 24.
     '''
 
     hide_root = BooleanProperty(False)
     '''Use this property to show/hide the initial root node. If True, the root
-    node will be always considerate as an open node
+    node will be appear as a closed node.
 
-    :data:`hide_root` is a :class:`~kivy.properties.BooleanProperty`, default to
-    False.
+    :data:`hide_root` is a :class:`~kivy.properties.BooleanProperty`, defaults
+    to False.
     '''
 
     def get_selected_node(self):
@@ -506,9 +543,9 @@ class TreeView(Widget):
 
     selected_node = AliasProperty(get_selected_node, None,
                                   bind=('_selected_node', ))
-    '''Node selected by :func:`TreeView.select_node`, or by touch.
+    '''Node selected by :meth:`TreeView.select_node`, or by touch.
 
-    :data:`selected_node` is a :class:`~kivy.properties.AliasProperty`, default
+    :data:`selected_node` is a :class:`~kivy.properties.AliasProperty`, defaults
     to None, and is read-only.
     '''
 
@@ -518,9 +555,9 @@ class TreeView(Widget):
     root = AliasProperty(get_root, None, bind=('_root', ))
     '''Root node.
 
-    By default, the root node widget is a :class:`TreeViewLabel`, with the label
+    By default, the root node widget is a :class:`TreeViewLabel`, with text
     'Root'. If you want to change the default options passed to the widget
-    creation, you can use :data:`root_options` property::
+    creation, use the :data:`root_options` property::
 
         treeview = TreeView(root_options={
             'text': 'Root directory',
@@ -530,7 +567,7 @@ class TreeView(Widget):
     :class:`TreeViewLabel` instance. However, you cannot change the class used
     for root node yet.
 
-    :data:`root` is a :class:`~kivy.properties.AliasProperty`, default to
+    :data:`root` is a :class:`~kivy.properties.AliasProperty`, defaults to
     None, and is read-only. However, the content of the widget can be changed.
     '''
 
@@ -543,9 +580,9 @@ class TreeView(Widget):
     '''
 
     load_func = ObjectProperty(None)
-    '''Callback to use for asynchronous loading. If set, the asynchronous will
-    be automatically done. The callback must act as a Python generator function
-    : use yield to send data back to the treeview.
+    '''Callback to use for asynchronous loading. If set, asynchronous loading
+    will be automatically done. The callback must act as a Python generator
+    function, using yield to send data back to the treeview.
 
     The callback should be in the format::
 
@@ -553,8 +590,8 @@ class TreeView(Widget):
             for name in ('Item 1', 'Item 2'):
                 yield TreeViewLabel(text=name)
 
-    :data:`load_func` is a :class:`~kivy.properties.ObjectProperty`, default to
-    None.
+    :data:`load_func` is a :class:`~kivy.properties.ObjectProperty`, defaults
+    to None.
     '''
 
 
