@@ -1,3 +1,4 @@
+# pylint: disable=W0611
 '''
 Utils
 =====
@@ -36,7 +37,7 @@ def difference(set1, set2):
 
 def interpolate(value_from, value_to, step=10):
     '''Interpolate a value to another. Can be useful to smooth some transition.
-    For example ::
+    For example::
 
         # instead of setting directly
         self.pos = pos
@@ -60,7 +61,7 @@ def interpolate(value_from, value_to, step=10):
 def strtotuple(s):
     '''Convert a tuple string into tuple,
     with some security check. Designed to be used
-    with eval() function ::
+    with eval() function::
 
         a = (12, 54, 68)
         b = str(a)         # return '(12, 54, 68)'
@@ -86,7 +87,7 @@ def get_color_from_hex(s):
     if s.startswith('#'):
         return get_color_from_hex(s[1:])
 
-    value = [int(x, 16)/255. for x in split('([0-9a-f]{2})', s) if x != '']
+    value = [int(x, 16) / 255. for x in split('([0-9a-f]{2})', s) if x != '']
     if len(value) == 3:
         value.append(1)
     return value
@@ -134,13 +135,13 @@ def deprecated(func):
         if caller_id not in DEPRECATED_CALLERS:
             DEPRECATED_CALLERS.append(caller_id)
             warning = (
-                'Call to deprecated function %s in %s line %d.'
-                'Called from %s line %d'
-                ' by %s().') % (
-                func.__name__,
-                func.func_code.co_filename,
-                func.func_code.co_firstlineno + 1,
-                file, line, caller)
+                    'Call to deprecated function %s in %s line %d.'
+                    'Called from %s line %d'
+                    ' by %s().') % (
+                            func.__name__,
+                            func.func_code.co_filename,
+                            func.func_code.co_firstlineno + 1,
+                            file, line, caller)
             from kivy.logger import Logger
             Logger.warn(warning)
             if func.__doc__:
@@ -259,7 +260,7 @@ class OrderedDict(dict, DictMixin):
 
     def __eq__(self, other):
         if isinstance(other, OrderedDict):
-            return len(self)==len(other) and self.items() == other.items()
+            return len(self) == len(other) and self.items() == other.items()
         return dict.__eq__(self, other)
 
     def __ne__(self, other):
@@ -271,7 +272,7 @@ class QueryDict(dict):
 
     .. versionadded:: 1.0.4
 
-    ::
+  ::
 
         d = QueryDict()
         # create a key named toto, with the value 1
@@ -332,7 +333,7 @@ def platform():
 
     if _platform_android is None:
         try:
-            __import__('android')
+            import android
             _platform_android = True
         except ImportError:
             _platform_android = False
@@ -355,6 +356,7 @@ def platform():
         return 'linux'
     return 'unknown'
 
+
 def escape_markup(text):
     '''
     Escape markup characters found in the text. Intended to be used when markup
